Documentation
¶
Overview ¶
Package v1beta1 contains API Schema definitions for the infrastructure v1beta1 API group +kubebuilder:object:generate=true +groupName=infrastructure.cluster.x-k8s.io
Index ¶
- Constants
- Variables
- type DockerMachinePool
- func (in *DockerMachinePool) DeepCopy() *DockerMachinePool
- func (in *DockerMachinePool) DeepCopyInto(out *DockerMachinePool)
- func (in *DockerMachinePool) DeepCopyObject() runtime.Object
- func (d *DockerMachinePool) GetConditions() clusterv1.Conditions
- func (*DockerMachinePool) Hub()
- func (d *DockerMachinePool) SetConditions(conditions clusterv1.Conditions)
- type DockerMachinePoolInstanceStatus
- type DockerMachinePoolList
- type DockerMachinePoolMachineTemplate
- type DockerMachinePoolSpec
- type DockerMachinePoolStatus
- type DockerMachinePoolTemplate
- type DockerMachinePoolTemplateList
- type DockerMachinePoolTemplateResource
- type DockerMachinePoolTemplateSpec
Constants ¶
const (
// MachinePoolFinalizer allows ReconcileDockerMachinePool to clean up resources.
MachinePoolFinalizer = "dockermachinepool.infrastructure.cluster.x-k8s.io"
)
Variables ¶
var ( // GroupVersion is group version used to register these objects. GroupVersion = schema.GroupVersion{Group: "infrastructure.cluster.x-k8s.io", Version: "v1beta1"} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = schemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type DockerMachinePool ¶
type DockerMachinePool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DockerMachinePoolSpec `json:"spec,omitempty"`
Status DockerMachinePoolStatus `json:"status,omitempty"`
}
DockerMachinePool is the Schema for the dockermachinepools API.
func (*DockerMachinePool) DeepCopy ¶
func (in *DockerMachinePool) DeepCopy() *DockerMachinePool
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePool.
func (*DockerMachinePool) DeepCopyInto ¶
func (in *DockerMachinePool) DeepCopyInto(out *DockerMachinePool)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DockerMachinePool) DeepCopyObject ¶
func (in *DockerMachinePool) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DockerMachinePool) GetConditions ¶
func (d *DockerMachinePool) GetConditions() clusterv1.Conditions
GetConditions returns the set of conditions for this object.
func (*DockerMachinePool) Hub ¶
func (*DockerMachinePool) Hub()
func (*DockerMachinePool) SetConditions ¶
func (d *DockerMachinePool) SetConditions(conditions clusterv1.Conditions)
SetConditions sets the conditions on this object.
type DockerMachinePoolInstanceStatus ¶
type DockerMachinePoolInstanceStatus struct {
// Addresses contains the associated addresses for the docker machine.
// +optional
Addresses []clusterv1.MachineAddress `json:"addresses,omitempty"`
// InstanceName is the identification of the Machine Instance within the Machine Pool
InstanceName string `json:"instanceName,omitempty"`
// ProviderID is the provider identification of the Machine Pool Instance
// +optional
ProviderID *string `json:"providerID,omitempty"`
// Version defines the Kubernetes version for the Machine Instance
// +optional
Version *string `json:"version,omitempty"`
// Ready denotes that the machine (docker container) is ready
// +optional
Ready bool `json:"ready"`
// Bootstrapped is true when the kubeadm bootstrapping has been run
// against this machine
//
// Deprecated: This field will be removed in the next apiVersion.
// When removing also remove from staticcheck exclude-rules for SA1019 in golangci.yml
// +optional
Bootstrapped bool `json:"bootstrapped,omitempty"`
}
DockerMachinePoolInstanceStatus contains status information about a DockerMachinePool.
func (*DockerMachinePoolInstanceStatus) DeepCopy ¶
func (in *DockerMachinePoolInstanceStatus) DeepCopy() *DockerMachinePoolInstanceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolInstanceStatus.
func (*DockerMachinePoolInstanceStatus) DeepCopyInto ¶
func (in *DockerMachinePoolInstanceStatus) DeepCopyInto(out *DockerMachinePoolInstanceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerMachinePoolList ¶
type DockerMachinePoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []DockerMachinePool `json:"items"`
}
DockerMachinePoolList contains a list of DockerMachinePool.
func (*DockerMachinePoolList) DeepCopy ¶
func (in *DockerMachinePoolList) DeepCopy() *DockerMachinePoolList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolList.
func (*DockerMachinePoolList) DeepCopyInto ¶
func (in *DockerMachinePoolList) DeepCopyInto(out *DockerMachinePoolList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DockerMachinePoolList) DeepCopyObject ¶
func (in *DockerMachinePoolList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DockerMachinePoolList) Hub ¶
func (*DockerMachinePoolList) Hub()
type DockerMachinePoolMachineTemplate ¶
type DockerMachinePoolMachineTemplate struct {
// CustomImage allows customizing the container image that is used for
// running the machine
// +optional
CustomImage string `json:"customImage,omitempty"`
// PreLoadImages allows to pre-load images in a newly created machine. This can be used to
// speed up tests by avoiding e.g. to download CNI images on all the containers.
// +optional
PreLoadImages []string `json:"preLoadImages,omitempty"`
// ExtraMounts describes additional mount points for the node container
// These may be used to bind a hostPath
// +optional
ExtraMounts []infrav1.Mount `json:"extraMounts,omitempty"`
}
DockerMachinePoolMachineTemplate defines the desired state of DockerMachine.
func (*DockerMachinePoolMachineTemplate) DeepCopy ¶
func (in *DockerMachinePoolMachineTemplate) DeepCopy() *DockerMachinePoolMachineTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolMachineTemplate.
func (*DockerMachinePoolMachineTemplate) DeepCopyInto ¶
func (in *DockerMachinePoolMachineTemplate) DeepCopyInto(out *DockerMachinePoolMachineTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerMachinePoolSpec ¶
type DockerMachinePoolSpec struct {
// Template contains the details used to build a replica machine within the Machine Pool
// +optional
Template DockerMachinePoolMachineTemplate `json:"template"`
// ProviderID is the identification ID of the Machine Pool
// +optional
ProviderID string `json:"providerID,omitempty"`
// ProviderIDList is the list of identification IDs of machine instances managed by this Machine Pool
//+optional
ProviderIDList []string `json:"providerIDList,omitempty"`
}
DockerMachinePoolSpec defines the desired state of DockerMachinePool.
func (*DockerMachinePoolSpec) DeepCopy ¶
func (in *DockerMachinePoolSpec) DeepCopy() *DockerMachinePoolSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolSpec.
func (*DockerMachinePoolSpec) DeepCopyInto ¶
func (in *DockerMachinePoolSpec) DeepCopyInto(out *DockerMachinePoolSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerMachinePoolStatus ¶
type DockerMachinePoolStatus struct {
// Ready denotes that the machine pool is ready
// +optional
Ready bool `json:"ready"`
// Replicas is the most recently observed number of replicas.
// +optional
Replicas int32 `json:"replicas"`
// The generation observed by the deployment controller.
// +optional
ObservedGeneration int64 `json:"observedGeneration,omitempty"`
// Instances contains the status for each instance in the pool
// +optional
Instances []DockerMachinePoolInstanceStatus `json:"instances,omitempty"`
// Conditions defines current service state of the DockerMachinePool.
// +optional
Conditions clusterv1.Conditions `json:"conditions,omitempty"`
// InfrastructureMachineKind is the kind of the infrastructure resources behind MachinePool Machines.
// +optional
InfrastructureMachineKind string `json:"infrastructureMachineKind,omitempty"`
}
DockerMachinePoolStatus defines the observed state of DockerMachinePool.
func (*DockerMachinePoolStatus) DeepCopy ¶
func (in *DockerMachinePoolStatus) DeepCopy() *DockerMachinePoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolStatus.
func (*DockerMachinePoolStatus) DeepCopyInto ¶
func (in *DockerMachinePoolStatus) DeepCopyInto(out *DockerMachinePoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerMachinePoolTemplate ¶ added in v1.6.0
type DockerMachinePoolTemplate struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DockerMachinePoolTemplateSpec `json:"spec,omitempty"`
}
DockerMachinePoolTemplate is the Schema for the dockermachinepooltemplates API.
func (*DockerMachinePoolTemplate) DeepCopy ¶ added in v1.6.0
func (in *DockerMachinePoolTemplate) DeepCopy() *DockerMachinePoolTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolTemplate.
func (*DockerMachinePoolTemplate) DeepCopyInto ¶ added in v1.6.0
func (in *DockerMachinePoolTemplate) DeepCopyInto(out *DockerMachinePoolTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DockerMachinePoolTemplate) DeepCopyObject ¶ added in v1.6.0
func (in *DockerMachinePoolTemplate) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DockerMachinePoolTemplateList ¶ added in v1.6.0
type DockerMachinePoolTemplateList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []DockerMachinePoolTemplate `json:"items"`
}
DockerMachinePoolTemplateList contains a list of DockerMachinePoolTemplate.
func (*DockerMachinePoolTemplateList) DeepCopy ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateList) DeepCopy() *DockerMachinePoolTemplateList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolTemplateList.
func (*DockerMachinePoolTemplateList) DeepCopyInto ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateList) DeepCopyInto(out *DockerMachinePoolTemplateList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DockerMachinePoolTemplateList) DeepCopyObject ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DockerMachinePoolTemplateResource ¶ added in v1.6.0
type DockerMachinePoolTemplateResource struct {
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
ObjectMeta clusterv1.ObjectMeta `json:"metadata,omitempty"`
Spec DockerMachinePoolSpec `json:"spec"`
}
DockerMachinePoolTemplateResource describes the data needed to create a DockerMachine from a template.
func (*DockerMachinePoolTemplateResource) DeepCopy ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateResource) DeepCopy() *DockerMachinePoolTemplateResource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolTemplateResource.
func (*DockerMachinePoolTemplateResource) DeepCopyInto ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateResource) DeepCopyInto(out *DockerMachinePoolTemplateResource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerMachinePoolTemplateSpec ¶ added in v1.6.0
type DockerMachinePoolTemplateSpec struct {
Template DockerMachinePoolTemplateResource `json:"template"`
}
DockerMachinePoolTemplateSpec defines the desired state of DockerMachinePoolTemplate.
func (*DockerMachinePoolTemplateSpec) DeepCopy ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateSpec) DeepCopy() *DockerMachinePoolTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerMachinePoolTemplateSpec.
func (*DockerMachinePoolTemplateSpec) DeepCopyInto ¶ added in v1.6.0
func (in *DockerMachinePoolTemplateSpec) DeepCopyInto(out *DockerMachinePoolTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.